lzw.ByteDecoder

Package lzw :: Class ByteDecoder |
[frames] | no frames]

# Class ByteDecoder

source code

    object --+
             |
            ByteDecoder

Decodes, combines bit-unpacking and interpreting a codepoint stream, suitable for use with bytes generated by ByteEncoder.

See ByteDecoder for a usage example.

Instance Methods
__init__(self) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
decodefrombytes(self, bytesource) Given an iterator over BitPacked, Encoded bytes, Returns an iterator over the uncompressed bytes. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### decodefrombytes(self, bytesource) | source code
Given an iterator over BitPacked, Encoded bytes, Returns an iterator over the uncompressed bytes. Dual of ByteEncoder.encodetobytes. See ByteEncoder for an example of use.